==> deepin-ocr_1.1.2.tar.xz: BUILD/translations/deepin-ocr_mn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="mn" version="2.1">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <location filename="../src/mainwidget.cpp" line="314"/>
        <source>Recognizing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="56"/>
        <source>OCR Tool</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="15"/>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="17"/>
        <source>Cut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="20"/>
        <source>Select All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Paste</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-ocr_6.5.7.tar.xz: BUILD/translations/deepin-ocr_mn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="mn">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation>Текст олдоггүй</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation>Текст хураах</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation>TXT-р хадгалах</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <source>Recognizing</source>
        <translation>Онлойх</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation>Хураагдсан</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="56"/>
        <source>OCR Tool</source>
        <translation>OCR-ын үзүүлбэр</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="15"/>
        <source>Copy</source>
        <translation>Хураах</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="17"/>
        <source>Cut</source>
        <translation>Хурааж устгах</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="20"/>
        <source>Select All</source>
        <translation>Бүхийг сонгох</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Paste</source>
        <translation>Нууцах</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>Албан ёсны: Өгөж байгаа үзүүлбэрийн тодорхойлолт нь текстийн тодорхойлолтыг нэмэгдүүлнэ</translation>
    </message>
</context>
</TS>
